==> kubernetes-model-1.0.6-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentDetailsFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DeploymentDetailsFluent<T extends DeploymentDetailsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     List<VisitableBuilder<DeploymentCause, ?>> causes = new ArrayList();     String message;     Map<String, Object> additionalProperties = new HashMap();

    public T addToCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.add(builder);this.causes.add(builder);} return (T)this;
    }
    public List<DeploymentCause> getCauses(){
    return build(causes);
    }
    public T withCauses( List<DeploymentCause> causes){
    this.causes.clear();if (causes != null) {for (DeploymentCause item : causes){this.addToCauses(item);}} return (T) this;
    }
    public T withCauses( DeploymentCause ...causes){
    this.causes.clear(); if (causes != null) {for (DeploymentCause item :causes){ this.addToCauses(item);}} return (T) this;
    }
    public CausesNested<T> addNewCause(){
    return new CausesNested<T>();
    }
    public CausesNested<T> addNewCauseLike( DeploymentCause item){
    return new CausesNested<T>(item);
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class CausesNested<N> extends DeploymentCauseFluent<CausesNested<N>> implements Nested<N>{

        private final DeploymentCauseBuilder builder;
    
             CausesNested (){
        this.builder = new DeploymentCauseBuilder(this);
        }
             CausesNested ( DeploymentCause item){
        this.builder = new DeploymentCauseBuilder(this, item);
        }
    
            public N endCause(){
            return and();
        }
            public N and(){
            return (N) DeploymentDetailsFluent.this.addToCauses(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.15-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentDetailsFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DeploymentDetailsFluent<T extends DeploymentDetailsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     List<VisitableBuilder<DeploymentCause, ?>> causes = new ArrayList();     String message;     Map<String, Object> additionalProperties = new HashMap();

    public T addToCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.add(builder);this.causes.add(builder);} return (T)this;
    }
    public T removeFromCauses( DeploymentCause ...items){
    for (DeploymentCause item : items) {DeploymentCauseBuilder builder = new DeploymentCauseBuilder(item);_visitables.remove(builder);this.causes.remove(builder);} return (T)this;
    }
    public List<DeploymentCause> getCauses(){
    return build(causes);
    }
    public T withCauses( List<DeploymentCause> causes){
    this.causes.clear();if (causes != null) {for (DeploymentCause item : causes){this.addToCauses(item);}} return (T) this;
    }
    public T withCauses( DeploymentCause ...causes){
    this.causes.clear(); if (causes != null) {for (DeploymentCause item :causes){ this.addToCauses(item);}} return (T) this;
    }
    public CausesNested<T> addNewCause(){
    return new CausesNested<T>();
    }
    public CausesNested<T> addNewCauseLike( DeploymentCause item){
    return new CausesNested<T>(item);
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
DeploymentDetailsFluent that = (DeploymentDetailsFluent) o;
if (causes != null ? !causes.equals(that.causes) :that.causes != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class CausesNested<N> extends DeploymentCauseFluent<CausesNested<N>> implements Nested<N>{

        private final DeploymentCauseBuilder builder;
    
             CausesNested ( DeploymentCause item){
        this.builder = new DeploymentCauseBuilder(this, item);
        }
             CausesNested (){
        this.builder = new DeploymentCauseBuilder(this);
        }
    
            public N endCause(){
            return and();
        }
            public N and(){
            return (N) DeploymentDetailsFluent.this.addToCauses(builder.build());
        }
    
}


}
